.. Please when editing this file make sure to keep it matching the
   docs in ../configuration.rst:reference_to_examples

sphinx_gallery.gen_gallery
==========================

.. automodule:: sphinx_gallery.gen_gallery

   
   

   Functions
   ---------

   

   .. autofunction:: check_duplicate_filenames

   .. _sphx_glr_backref_sphinx_gallery.gen_gallery.check_duplicate_filenames:

   .. minigallery:: sphinx_gallery.gen_gallery.check_duplicate_filenames
       :add-heading:

   .. autofunction:: check_spaces_in_filenames

   .. _sphx_glr_backref_sphinx_gallery.gen_gallery.check_spaces_in_filenames:

   .. minigallery:: sphinx_gallery.gen_gallery.check_spaces_in_filenames
       :add-heading:

   .. autofunction:: collect_gallery_files

   .. _sphx_glr_backref_sphinx_gallery.gen_gallery.collect_gallery_files:

   .. minigallery:: sphinx_gallery.gen_gallery.collect_gallery_files
       :add-heading:

   .. autofunction:: cost_name_key

   .. _sphx_glr_backref_sphinx_gallery.gen_gallery.cost_name_key:

   .. minigallery:: sphinx_gallery.gen_gallery.cost_name_key
       :add-heading:

   .. autofunction:: generate_gallery_rst

   .. _sphx_glr_backref_sphinx_gallery.gen_gallery.generate_gallery_rst:

   .. minigallery:: sphinx_gallery.gen_gallery.generate_gallery_rst
       :add-heading:

   .. autofunction:: get_default_config_value

   .. _sphx_glr_backref_sphinx_gallery.gen_gallery.get_default_config_value:

   .. minigallery:: sphinx_gallery.gen_gallery.get_default_config_value
       :add-heading:

   .. autofunction:: get_subsections

   .. _sphx_glr_backref_sphinx_gallery.gen_gallery.get_subsections:

   .. minigallery:: sphinx_gallery.gen_gallery.get_subsections
       :add-heading:

   .. autofunction:: parse_config

   .. _sphx_glr_backref_sphinx_gallery.gen_gallery.parse_config:

   .. minigallery:: sphinx_gallery.gen_gallery.parse_config
       :add-heading:

   .. autofunction:: setup

   .. _sphx_glr_backref_sphinx_gallery.gen_gallery.setup:

   .. minigallery:: sphinx_gallery.gen_gallery.setup
       :add-heading:

   .. autofunction:: setup_module

   .. _sphx_glr_backref_sphinx_gallery.gen_gallery.setup_module:

   .. minigallery:: sphinx_gallery.gen_gallery.setup_module
       :add-heading:

   .. autofunction:: summarize_failing_examples

   .. _sphx_glr_backref_sphinx_gallery.gen_gallery.summarize_failing_examples:

   .. minigallery:: sphinx_gallery.gen_gallery.summarize_failing_examples
       :add-heading:

   .. autofunction:: touch_empty_backreferences

   .. _sphx_glr_backref_sphinx_gallery.gen_gallery.touch_empty_backreferences:

   .. minigallery:: sphinx_gallery.gen_gallery.touch_empty_backreferences
       :add-heading:

   .. autofunction:: write_computation_times

   .. _sphx_glr_backref_sphinx_gallery.gen_gallery.write_computation_times:

   .. minigallery:: sphinx_gallery.gen_gallery.write_computation_times
       :add-heading:

   .. autofunction:: write_junit_xml

   .. _sphx_glr_backref_sphinx_gallery.gen_gallery.write_junit_xml:

   .. minigallery:: sphinx_gallery.gen_gallery.write_junit_xml
       :add-heading:
   
   

   
   

   Classes
   -------

   
   .. autoclass:: DefaultResetArgv
      :members:

   .. _sphx_glr_backref_sphinx_gallery.gen_gallery.DefaultResetArgv:

   .. minigallery:: sphinx_gallery.gen_gallery.DefaultResetArgv
       :add-heading:
   
   

   
   
   